var _edict = false;

try {
  _edict = org.mozdev.moji.dict.EDict;
} catch (e)
{
  try {
    _edict = EDict;
  } catch (e) { }
}

if ( _edict )
 _edict.prototype.mojiscnde = {
  _analyzeEntry : function(ent) {
    var ret = { terms: new Array(), meanings: new Array() };
    var meaningcount = 0;
    
    var parts = ent.split("/");
    
    for ( var i = 0; i < parts.length; i++ ) {
      // skip empty entries (at the beginning and the end...)
      if ( parts[i] == "" )
        continue;
      
      var test = parts[i].match(/^\[([0-9]+)\]$/);
      
      if ( test ) {
        meaningcount = test[1];
        
        if ( ! ret.meanings[meaningcount] ) {
          ret.meanings[meaningcount] = { terms: new Array(), translations: new Array() };
        }
        
        continue;
      }
      
      var test = parts[i].match(/^\{(.*)\}$/);
      
      if ( test ) {
        var t = test[1].split(",");
        var ta = Array();
        
        for ( var j = 0; j < t.length; j++ ) {
          ta.push({abbrev: t[j], full: t[j]});
        }
        
        if ( meaningcount == 0 )
          ret.terms.push(ta);
        else
          ret.meanings[meaningcount].terms.push(ta);
          
        continue;
      }

      if ( meaningcount == 0 ) {
        if ( ! ret.meanings[1] ) {
          ret.meanings[1] = { terms: new Array(), translations: new Array() };
        }
        meaningcount = 1;
      }
      
      ret.meanings[meaningcount].translations.push(parts[i]);
    }
    
    return ret;
  },
  
  _getFirstMeaning : function(ent) {
    // This regexp extracts the first meaning entry from the dictionary entry.
    // the first meaning is used in the tree view next to the search word.
    // It assumes the following structure of an entry:
    // "word word [reading] explanations"
    // explanation is an arbitrary list of entries each of them between slashes "/", e.g.
    //   /a/b/c/d/e/f/
    // The first meaning is the first meaningful entry. There are a couple of structural
    // and grammatical note entries which we discard. Those are:
    // -  e.g. "[1]", which numbers various different meanings for one word.
    // -  e.g. "{Zool.}", which explains the source or origin of the word or the area of use.
    // -  e.g. "(schriftspr.)", when it is used e.g. in written language only.
    // 
    // thus the regexp consists of the following parts:
    // "^[^ ]* " matching the beginning of the entry up to the first space = word
    // "(\[[^\]]*\] )?" an optional reading entry between [] followed by a space.
    // "(\/(\{[^}]*\}|\[[^\]*]\]|\([^\)]*\)))*" an arbitrary+optional list of note entries [], {} and ()
    //                each starting with a slash
    // "\/([^\/]*)/)" that is the first entry then that does not match the one above = first meaning
    var m = ent.match(/^[^ ]* [^ ]* (\[[^\]]*\] )?(\/(\{[^}]*\}|\[[^\]*]\]|\([^\)]*\)))*\/([^\/]*)/);
	if ( m && m[4] ) 
	  fm = m[4];
	else
	  fm = "invalid dictionary entry";
	    
    // the dictionary for instance does contain additional grammatical information in
    // the first explanation, e.g. (n) for nouns. These are removed here.
    fm = fm.replace(/\([a-zA-Z0-9\-]+\)/g,"");
    return fm;
  },
  
  _splitEntry : function(entry) {
    // this dictionaries contains two word definitions at the beginning.
    return entry.txt.replace(
                /^([^ ]* [^ ]*) (\[([^\]]*)\] )?\/(.*)\//,"$1\n$3\n$4"
                ).split("\n");

  }
}
